nvector.objects.delta_L — nvector 0.7.5 documentation

# nvector.objects.delta_L

`delta_L`(point_a, point_b, wander_azimuth=0)

  Returns cartesian delta vector from positions a to b decomposed in L.

  Parameters
    point_a, point_b: Nvector, GeoPoint or ECEFvector objects

      position a and b, decomposed in E.

    wander_azimuth: real scalar

      Angle [rad] between the x-axis of L and the north direction.

  See also

  `delta_E`, `delta_N`